@@ -38,8 +38,6 @@
 #' variable to a single row, excluding the first level rather than showing both.
 #' @param yname.row Logical value for whether to include a row displaying the
 #' name of the \code{y} variable and indent the factor levels.
-#' @param indent.spaces Integer value specifying how many spaces to indent
-#' factor levels. Only used if \code{yname.row = TRUE}.
 #' @param text.label Character string with text to put after the \code{y}
 #' variable name, identifying what cell values and parentheses represent.
 #' @param quantiles Numeric value. If specified, table compares \code{y} across
@@ -47,51 +45,27 @@
 #' @param quantile.vals Logical value for whether labels for \code{x} quantiles
 #' should show quantile number and corresponding range, e.g. Q1 [0.00, 0.25),
 #' rather than just the quantile number.
-#' @param latex Logical value for whether to format table so it is
-#' ready for printing in LaTeX via \code{\link[xtable]{xtable}} or
-#' \code{\link[knitr]{kable}}.
 #' @param decimals Numeric value specifying number of decimal places for numbers
 #' other than p-values.
 #' @param formatp.list List of arguments to pass to \code{\link[tab]{formatp}}.
 #' @param n.headings Logical value for whether to display group sample sizes in
 #' parentheses in column headings.
-#' @param print.html Logical value for whether to write a .html file with the
-#' table to the current working directory.
-#' @param html.filename Character string specifying the name of the .html file
-#' that gets written if \code{print.html = TRUE}.
+#' @param kable Logical value for whether to return a
+#' \code{\link[knitr]{kable}}.
 #'
 #'
-#' @return Data frame which you can print in R (e.g. with \strong{xtable}'s
-#' \code{\link[xtable]{xtable}} or \strong{knitr}'s \code{\link[knitr]{kable}})
-#' or export to Word, Excel, or some other program. To export the table, set
-#' \code{print.html = TRUE}. This will result in a .html file being written to
-#' your current working directory, which you can open and copy/paste into your
-#' document.
+#' @return \code{\link[knitr]{kable}}.
 #'
 #'
 #' @examples
 #' # Compare sex distribution by group
 #' (freqtable1 <- tabfreq(Sex ~ Group, data = tabdata))
 #'
-#' # Same as previous, but specifying input vectors rather than formula
-#' (freqtable2 <- tabfreq(x = tabdata$Group, y = tabdata$Sex))
-#'
-#' # Same as previous, but showing male row only and percent (SE) rather than n
-#' # (percent)
-#' (freqtable3 <- tabfreq(Sex ~ Group, data = tabdata,
+#' # Same as previous, but showing male row only and % (SE) rather than n (%)
+#' (freqtable2 <- tabfreq(Sex ~ Group, data = tabdata,
 #'                        cell = "col.percent", parenth = "se",
 #'                        compress.binary = TRUE))
 #'
-#' # Create single table comparing sex and race in control vs. treatment group.
-#' # Drop missing observations first.
-#' tabdata2 <- subset(tabdata, ! is.na(Sex) & ! is.na(Race))
-#' (freqtable4 <- rbind(tabfreq(Sex ~ Group, data = tabdata2),
-#'                      tabfreq(Race ~ Group, data = tabdata2)))
-#'
-#' # Same as previous, but using tabmulti for convenience
-#' #(freqtable5 <- tabmulti(data = d, xvarname = "Group",
-#' #                        yvarnames = c("Sex", "Race")))
-#'
 #'
 #' @export
 tabfreq <- function(formula = NULL,
@@ -108,16 +82,13 @@ tabfreq <- function(formula = NULL,
                     ylevels = NULL,
                     compress.binary = FALSE,
                     yname.row = TRUE,
-                    indent.spaces = 3,
                     text.label = NULL,
                     quantiles = NULL,
                     quantile.vals = FALSE,
-                    latex = TRUE,
                     decimals = 1,
                     formatp.list = NULL,
                     n.headings = FALSE,
-                    print.html = FALSE,
-                    html.filename = "table1.html") {
+                    kable = TRUE) {
 
   # Error checking
   if (! is.null(formula) && class(formula) != "formula") {
@@ -157,9 +128,6 @@ tabfreq <- function(formula = NULL,
   if (! is.logical(yname.row)) {
     stop("The input 'yname.row' must be a logical.")
   }
-  if (! is.null(indent.spaces) && ! (is.numeric(indent.spaces) && indent.spaces >= 0 && indent.spaces == as.integer(indent.spaces))) {
-    stop("The input 'indent.spaces' must be a non-negative integer.")
-  }
   if (! is.null(text.label) && ! is.character(text.label)) {
     stop("The input 'text.label' must be a character string.")
   }
@@ -170,9 +138,6 @@ tabfreq <- function(formula = NULL,
   if (! is.logical(quantile.vals)) {
     stop("The input 'quantile.vals' must be a logical.")
   }
-  if (! is.logical(latex)) {
-    stop("The input 'latex' must be a logical.")
-  }
   if (! (is.numeric(decimals) && decimals >= 0 &&
          decimals == as.integer(decimals))) {
     stop("The input 'decimals' must be a non-negative integer.")
@@ -185,11 +150,8 @@ tabfreq <- function(formula = NULL,
   if (! is.logical(n.headings)) {
     stop("The input 'n.headings' must be a logical.")
   }
-  if (! is.logical(print.html)) {
-    stop("The input 'print.html' must be a logical.")
-  }
-  if (! is.character("html.filename")) {
-    stop("The input 'html.filename' must be a character string.")
+  if (! is.logical(kable)) {
+    stop("The input 'kable' must be a logical.")
   }
 
   # If formula specified, figure out x and y
@@ -197,8 +159,8 @@ tabfreq <- function(formula = NULL,
     varnames <- all.vars(formula)
     xvarname <- varnames[2]
     yvarname <- varnames[1]
-    x <- data[, xvarname]
-    y <- data[, yvarname]
+    x <- data[[xvarname]]
+    y <- data[[yvarname]]
     if (is.null(yname)) {
       yname <- yvarname
     }
@@ -306,7 +268,7 @@ tabfreq <- function(formula = NULL,
       if (cell == "counts") {
         part1 <- rowsums.counts
       } else if (cell %in% c("tot.percent", "col.percent")) {
-        part1 <- sprintf(spf, rowsums.counts / n)
+        part1 <- sprintf(spf, rowsums.counts / n * 100)
       }
       if (parenth == "none") {
         part2 <- NULL
@@ -419,7 +381,7 @@ tabfreq <- function(formula = NULL,
 
   # Add yname row and indent ylevels if requested
   if (yname.row) {
-    spaces <- paste(rep(" ", indent.spaces), collapse = "")
+    spaces <- "&nbsp; &nbsp; &nbsp;"
     row1 <- df[1, , drop = FALSE]
     df[, 1] <- paste(spaces, df[, 1], sep = "")
     df <- rbind(c(yname, rep("", ncol(df) - 1)), df)
@@ -458,28 +420,8 @@ tabfreq <- function(formula = NULL,
 
   }
 
-  # Print html version of table if requested
-  if (print.html) {
-
-    df.xtable <- xtable(
-      df,
-      align = paste("ll", paste(rep("r", ncol(df) - 1), collapse = ""), sep = "", collapse = "")
-    )
-    ampersands <- paste(rep("&nbsp ", indent.spaces), collapse = "")
-    print(df.xtable, include.rownames = FALSE, type = "html",
-          file = html.filename, sanitize.text.function = function(x) {
-            ifelse(substr(x, 1, 1) == " ", paste(ampersands, x), x)
-          })
-
-  }
-
-  # Reformat for latex if requested
-  if (latex && yname.row) {
-    slashes <- paste(rep("\\ ", indent.spaces), collapse = "")
-    df$Variable <- gsub(pattern = spaces, replacement = slashes, x = df$Variable, fixed = TRUE)
-  }
-
   # Return table
-  return(df)
+  if (! kable) return(df)
+  return(df %>% kable(escape = FALSE) %>% kable_styling(full_width = FALSE))
 
 }
